import random
import encipher_crypto
import nltk
from nltk.tokenize.treebank import TreebankWordDetokenizer


class encipher:

    """Generates encrypted text. Used for the NN and test_generator"""

    def __init__(self):
        """Inits the encipher object """
        self.text = self.read_text()[0:200]
        self.MAX_SENTENCE_LENGTH = 1
        # ntlk.download("punkt")
        self.crypto = encipher_crypto.encipher_crypto()

    def read_text(self):
        f = open("hansard.txt", encoding="ISO-8859-1")
        x = f.read()
        splits = nltk.tokenize.sent_tokenize(x)
        return splits

    def getRandomSentence(self):
        return TreebankWordDetokenizer().detokenize(
            random.sample(self.text, random.randint(1, self.MAX_SENTENCE_LENGTH))
        )

    def getRandomEncryptedSentence(self):
        sents = self.getRandomSentence()

        sentsEncrypted = self.crypto.randomEncrypt(sents)
        return {"PlainText Sentences": sents, "Encrypted Texts": sentsEncrypted}


# obj = encipher()
# print(obj.getRandomEncryptedSentence())



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

modules = \
['enciphey']
install_requires = \
['cipheycore>=0.1.5-rc.4,<0.2.0',
 'cipheydists>=0.1.3,<0.2.0',
 'unicode>=2.7,<3.0']

setup_kwargs = {
    'name': 'enciphey',
    'version': '0.1.1',
    'description': 'Randomly chooses an encryption',
    'long_description': None,
    'author': 'Brandon',
    'author_email': 'brandon@skerritt.blog',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'py_modules': modules,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
